import { For, JSXElement, createResource } from "solid-js";

import { getComments } from "../Util/api";
import { Comment } from "./Comment";

/**
 * CommentSection is a component that displays a collection of comments.
 * @param {Object} props The properties for the CommentSection component.
 * @param {string} props.postId The id of the post that the comments are a reply to.
 * @returns {JSXElement} A JSXElement that contains a collection of comments.
 */
export function CommentSection({ postId }: { postId: string }): JSXElement {
  const [comments] = createResource(postId, () => getComments(postId, 10, 0));

  return (
    <section class="p-5 my-5 bg-base-200 border-b-2 border-b-primary ">
      <For each={comments()!}>{(comment) => <Comment comment={comment} />}</For>
    </section>
  );
}
